@@ -7,6 +7,9 @@ DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
 
 . $DRBL_SCRIPT_PATH/sbin/drbl-conf-functions
 
+# Load the config in ocs-live.conf. This is specially for DRBL/Clonezilla live. It will overwrite some settings of /opt/drbl/conf/drbl-ocs.conf, such as $DIA...
+[ -e "/etc/ocs/ocs-live.conf" ] && . /etc/ocs/ocs-live.conf
+
 # Settings
 # try IP from 192.168."100".254
 private_IP_alias_eth_def="100"
@@ -65,6 +68,7 @@ case "$switch" in
        # Check if $ocsroot is a mountpoint or not, if not, we have to mount it.
        prepare_ocsroot_opt=""
        if ! mountpoint $ocsroot &>/dev/null; then
+         echo "Directory $ocsroot is not a mount point. Will try to mount $ocsroot..."
          prepare_ocsroot_opt="--prepare-ocsroot"
        fi	        
        drbl-live.sh $prepare_ocsroot_opt --skip-pause-in-the-end --no-prompt-drbl-live start
